@@ -5,8 +5,8 @@
 static PyObject *
 parsetime_parsetime(PyObject *self, PyObject *pytimestring)
 {
-    int argc = 2;
-    char *argv[argc];
+    int argc = 1;
+    char *argv[1];
     const char *timestring;
     time_t result;
 
@@ -14,8 +14,7 @@ parsetime_parsetime(PyObject *self, PyObject *pytimestring)
         return NULL;
     }
 
-    argv[0] = "parsetime";
-    argv[1] = (char*)timestring;
+    argv[0] = (char*)timestring;
 
     result = parsetime(argc, argv);
     return Py_BuildValue("i", result);
